# MuReNN: Multiresolution Neural Networks

```tex
@inproceedings{lostanlen2023fitting,
  title={Fitting Auditory Filterbanks with Multiresolution Neural Networks},
  author={Lostanlen, Vincent and Haider, Daniel and Han, Han and Lagrange, Mathieu and Balazs, Peter and Ehler, Martin},
  booktitle={Proceedings of the IEEE Workshop on Applications of Signal Processing to Audio and Acoustics (WASPAA)},
  pages={1--5},
  year={2023},
  organization={IEEE}
}
```